.. raw:: html

     <embed>
          <p align="center">
               <div align="center">
                    <a href="https://github.com/parashardhapola/scarf">
                         <img src="https://rawcdn.githack.com/parashardhapola/scarf/eefd75a0893a8903b8fcf8c51b5e7cb8e672a272/docs/source/logo_wide.png" alt="Scarf logo" width="600px" />
                    </a>
                    <h3>A framework for memory-efficient analysis of single-cell genomics data</h3>
               </div>
          </p>

          <br />

          <p align="center">
               <a href="https://pypi.org/project/scarf">
                    <img src="https://img.shields.io/pypi/v/scarf.svg" alt="PyPiVersion" />
               </a>
               <a href="https://scarf.readthedocs.io">
                    <img src="https://readthedocs.org/projects/scarf/badge/?version=latest" alt="ReadTheDocs" />
               </a>
               <a href="https://github.com/parashardhapola/scarf/actions/workflows/pytest.yml">
                    <img src="https://github.com/parashardhapola/scarf/actions/workflows/pytest.yml/badge.svg" alt="TestStatus" />
               </a>
               <a href="https://codecov.io/gh/parashardhapola/scarf">
                    <img src="https://codecov.io/gh/parashardhapola/scarf/branch/master/graph/badge.svg?token=ZvJXuYq3pd" alt="TestCoverage" />
               </a>
               <a href="https://pepy.tech/project/scarf">
                    <img src="https://pepy.tech/badge/scarf" alt="PyPiDownloads" />
               </a>
               <a href="https://github.com/psf/black">
                    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="GitHub tweet" />
               </a>
          </p>
          
          <h4 align="center">
               <a href="https://scarf.readthedocs.io/en/latest/install.html"> 🔌 Installation</a> |
               <a href="http://scarf.rtfd.io"> 📖 Documentation</a> |
               <a href="https://scarf.readthedocs.io/en/latest/vignettes/basic_tutorial_scRNAseq.html"> 🚀 Getting started</a> |
               <a href="https://www.nature.com/articles/s41467-022-32097-3">📝 Article in Nature Comm</a>
          </h4>

          <br />
         
          <p align="center">
               <strong>Need support?</strong> Create an issue <a href="https://github.com/parashardhapola/scarf/issues">on Github</a> and connect with maintainers on this <a href="https://scarf-group.slack.com/archives/C0418C7RXU4">Slack channel</a>.
          </p>
         
     </embed>
